'use strict';
//Require dependencies
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var path = require('path');
var mkdirp = require('mkdirp');

module.exports = yeoman.Base.extend({
	initializing: function () {
    	this.props = {};
  	},
  	constructor: function () {
		yeoman.Base.apply(this, arguments);
	},
	prompting: function() {
	  var done = this.async();

	  	this.log(yosay(
	      	'Thanks for use' + chalk.red('web-metrocss') + ' generator!'
	   	));

	  	var prompts = [{
	        	type: 'input',
	        	name: 'name',
	        	message: 'Please input project name (web_metrocss):',
	        	default: 'web_metrocss'
	      	},{
	        	type: 'input',
	        	name: 'desc',
	        	message: 'Please input project description:'
	      	},{
	        	type: 'input',
	        	name: 'main',
	        	message: 'Main file (main.js):',
	        	default: 'main.js'
	      	},{
	        	type: 'input',
	        	name: 'author',
	        	message: 'Author (user):',
	        	default: 'user'
	      	},{
	        	type: 'list',
	        	name: 'license',
	        	message: 'Please choose license:',
	        	choices: ['MIT', 'ISC'],
	        	default: 'ISC'
	      	},{
	        	type: 'input',
	        	name: 'homepage',
	        	message: 'Please input homepage:'
	      	}];
	    return this.prompt(prompts).then(function (props) {
	      	this.props = props;
	      	done();
	    }.bind(this));
	},
	default: function () {
    	if (path.basename(this.destinationPath()) !== this.props.name) {
      		this.log('create project ' + this.props.name);
      		mkdirp(this.props.name);
      		this.destinationRoot(this.destinationPath(this.props.name));
    	}
  	},
	writing: {
		gulpfile: function () {
			this.fs.copy(
				this.templatePath('_gulpfile.js'),
				this.destinationPath('gulpfile.js')				
			);
		},
		packageJSON: function () {
			this.fs.copyTpl(
				this.templatePath('_package.json'),
				this.destinationPath('package.json'),
				{
					name: this.props.name,
	              	desc: this.props.desc,
	              	main: this.props.main,
	              	author: this.props.author,
	              	license: this.props.license,
	              	homepage: this.props.homepage,
				}
			);
		},
		bower: function(){
			this.fs.copyTpl(
	          	this.templatePath('_bower.json'),
	          	this.destinationPath('bower.json'), {
	              	name: this.props.name
	          	}
	      	);
	      	this.fs.copyTpl(
	          	this.templatePath('_bowerrc'),
	          	this.destinationPath('.bowerrc'), {
	              	name: this.props.name
	          	}
	      	);
		},
		mainFlie:function(){
			this.fs.copy(
				this.templatePath('_csslintrc.json'),
				this.destinationPath('csslintrc.json')				
			);
			this.fs.copy(
				this.templatePath('_jshint.json'),
				this.destinationPath('jshint.json')				
			);
			this.fs.copy(
				this.templatePath('_main.js'),
				this.destinationPath('res/js/main.js')				
			);
			this.fs.copy(
				this.templatePath('_main.css'),
				this.destinationPath('res/css/main.css')				
			);
			this.fs.copy(
				this.templatePath('_icon.png'),
				this.destinationPath('res/img/icon.png')				
			);
			this.fs.copy(
				this.templatePath('_index.html'),
				this.destinationPath('res/html/index.html')				
			);
			mkdirp("res/img");
		}
	},
	install: function () {
        var done = this.async();
        this.spawnCommand('npm', ['install'])
            .on('exit', function (code) {
                if (code) {
                    done(new Error('code:' + code));
                } else {
                    done();
                }
            })
            .on('error', done);
        this.spawnCommand('bower', ['install'])
            .on('exit', function (code) {
                if (code) {
                    done(new Error('code:' + code));
                } else {
                    done();
                }
            })
            .on('error', done);
    }
});


